@@ -20,14 +20,14 @@
 #include "k3bisooptions.h"
 #include <config-k3b.h>
 
-#include <KDebug>
-#include <KUrl>
-
-#include <QFile>
-#include <QFileInfo>
-#include <QRegExp>
-#include <QString>
-#include <QStringList>
+#include <QtCore/QDebug>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QMimeDatabase>
+#include <QtCore/QRegExp>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+#include <QtCore/QUrl>
 
 #include <errno.h>
 #include <string.h>
@@ -55,8 +55,8 @@ bool K3b::operator>( const K3b::FileItem::Id& id1, const K3b::FileItem::Id& id2
 
 
 
-K3b::FileItem::FileItem( const QString& filePath, K3b::DataDoc* doc, K3b::DirItem* dir, const QString& k3bName, const ItemFlags& flags )
-    : K3b::DataItem( doc, dir, flags | FILE ),
+K3b::FileItem::FileItem( const QString& filePath, K3b::DataDoc& doc, const QString& k3bName, const ItemFlags& flags )
+    : K3b::DataItem( flags | FILE ),
       m_replacedItemFromOldSession(0),
       m_localPath(filePath)
 {
@@ -71,17 +71,17 @@ K3b::FileItem::FileItem( const QString& filePath, K3b::DataDoc* doc, K3b::DirIte
         }
         else {
             init( filePath, k3bName, doc, &statBuf, 0 );
-            kError() << "(KFileItem) stat failed: " << strerror(errno) << endl;
+            qCritical() << "(KFileItem) stat failed: " << QString::fromLocal8Bit( ::strerror(errno) ) << endl;
         }
     }
     else {
-        kError() << "(KFileItem) lstat failed: " << strerror(errno) << endl;
+        qCritical() << "(KFileItem) lstat failed: " << QString::fromLocal8Bit( ::strerror(errno) ) << endl;
         if( k3b_stat( QFile::encodeName(filePath), &followedStatBuf ) == 0 ) {
             init( filePath, k3bName, doc, 0, &followedStatBuf );
         }
         else {
             init( filePath, k3bName, doc, 0, 0 );
-            kError() << "(KFileItem) stat failed: " << strerror(errno) << endl;
+            qCritical() << "(KFileItem) stat failed: " << QString::fromLocal8Bit( ::strerror(errno) ) << endl;
         }
     }
 }
@@ -89,8 +89,8 @@ K3b::FileItem::FileItem( const QString& filePath, K3b::DataDoc* doc, K3b::DirIte
 
 K3b::FileItem::FileItem( const k3b_struct_stat* stat,
                           const k3b_struct_stat* followedStat,
-                          const QString& filePath, K3b::DataDoc* doc, K3b::DirItem* dir, const QString& k3bName, const ItemFlags& flags )
-    : K3b::DataItem( doc, dir, flags | FILE ),
+                          const QString& filePath, K3b::DataDoc& doc, const QString& k3bName, const ItemFlags& flags )
+    : K3b::DataItem( flags | FILE ),
       m_replacedItemFromOldSession(0),
       m_localPath(filePath)
 {
@@ -124,7 +124,7 @@ K3b::DataItem* K3b::FileItem::copy() const
 }
 
 
-KMimeType::Ptr K3b::FileItem::mimeType() const
+QMimeType K3b::FileItem::mimeType() const
 {
     return m_mimeType;
 }
@@ -141,7 +141,10 @@ KIO::filesize_t K3b::FileItem::itemSize( bool followSymlinks ) const
 
 K3b::FileItem::Id K3b::FileItem::localId() const
 {
-    return localId( doc() ? doc()->isoOptions().followSymbolicLinks() || !doc()->isoOptions().createRockRidge() : false );
+    if( DataDoc* doc = getDoc() )
+        return localId( doc->isoOptions().followSymbolicLinks() || !doc->isoOptions().createRockRidge() );
+    else
+        return localId( false );
 }
 
 
@@ -174,7 +177,7 @@ QString K3b::FileItem::localPath() const
 
 K3b::DirItem* K3b::FileItem::getDirItem() const
 {
-    return getParent();
+    return parent();
 }
 
 
@@ -189,8 +192,10 @@ bool K3b::FileItem::isValid() const
     if( isSymLink() ) {
 
         // this link is not valid if we cannot follow it if we want to
-        if( doc()->isoOptions().followSymbolicLinks() ) {
-            return QFile::exists( K3b::resolveLink( localPath() ) );
+        if( DataDoc* doc = getDoc() ) {
+            if( doc->isoOptions().followSymbolicLinks() ) {
+                return QFile::exists( K3b::resolveLink( localPath() ) );
+            }
         }
 
         QString dest = linkDest();
@@ -199,7 +204,7 @@ bool K3b::FileItem::isValid() const
             return false;  // absolut links can never be part of the compilation!
 
         // parse the link
-        K3b::DirItem* dir = getParent();
+        K3b::DirItem* dir = parent();
 
         QStringList tokens = dest.split( QRegExp("/+") );  // two slashes or more do the same as one does!
 
@@ -245,7 +250,7 @@ bool K3b::FileItem::isValid() const
 
 void K3b::FileItem::init( const QString& filePath,
                           const QString& k3bName,
-                          DataDoc* doc,
+                          DataDoc& doc,
                           const k3b_struct_stat* stat,
                           const k3b_struct_stat* followedStat )
 {
@@ -258,7 +263,7 @@ void K3b::FileItem::init( const QString& filePath,
         m_size = (KIO::filesize_t)stat->st_size;
         if( S_ISLNK(stat->st_mode) )
             setFlags( flags() | SYMLINK );
-        
+
         //
         // integrate the device number into the inode since files on different
         // devices may have the same inode number!
@@ -267,16 +272,14 @@ void K3b::FileItem::init( const QString& filePath,
         m_id.device = stat->st_dev;
     }
     else {
-        m_size = K3b::filesize( filePath );
+        m_size = QFileInfo(filePath).size();
         m_id.inode = 0;
         m_id.device = 0;
 
         // since we have no proper inode info, disable the inode caching in the doc
-        if( doc ) {
-            K3b::IsoOptions o( doc->isoOptions() );
-            o.setDoNotCacheInodes( true );
-            doc->setIsoOptions( o );
-        }
+        K3b::IsoOptions o( doc.isoOptions() );
+        o.setDoNotCacheInodes( true );
+        doc.setIsoOptions( o );
     }
 
     if( isSymLink() ) {
@@ -300,7 +303,7 @@ void K3b::FileItem::init( const QString& filePath,
         m_idFollowed = m_id;
     }
 
-    m_mimeType = KMimeType::findByUrl( KUrl(filePath) );
+    m_mimeType = QMimeDatabase().mimeTypeForFile( filePath );
 
     // add automagically like a qlistviewitem
     if( parent() )
