@@ -25,22 +25,20 @@
 #include "k3bthroughputestimator.h"
 #include "k3bglobals.h"
 #include "k3bglobalsettings.h"
+#include "k3b_i18n.h"
 
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qregexp.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qdir.h>
-#include <q3socket.h>
-#include <q3socketdevice.h>
+#include <KIOCore/KIO/CopyJob>
+#include <KIOCore/KIO/DeleteJob>
+
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
 #include <QtCore/QFileInfo>
-
-#include <klocale.h>
-#include <kdebug.h>
-#include <kio/netaccess.h>
-#include <kstandarddirs.h>
-#include <ktemporaryfile.h>
+#include <QtCore/QRegExp>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+#include <QtCore/QTemporaryFile>
+#include <QtNetwork/QTcpSocket>
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -154,17 +152,16 @@ K3b::CdrdaoWriter::CdrdaoWriter( K3b::Device::Device* dev, K3b::JobHandler* hdl,
     if( socketpair(AF_UNIX,SOCK_STREAM,0,m_cdrdaoComm) )
     {
 #endif
-		kDebug() << "(K3b::CdrdaoWriter) could not open socketpair for cdrdao remote messages";
+		qDebug() << "(K3b::CdrdaoWriter) could not open socketpair for cdrdao remote messages";
 #ifndef Q_OS_WIN32
     }
     else
     {
         delete m_comSock;
-        m_comSock = new Q3Socket();
-        m_comSock->setSocket(m_cdrdaoComm[1]);
-        m_comSock->socketDevice()->setReceiveBufferSize(49152);
+        m_comSock = new QTcpSocket();
+        m_comSock->setSocketDescriptor( m_cdrdaoComm[1] );
+        m_comSock->setReadBufferSize(49152);
         // magic number from Qt documentation
-        m_comSock->socketDevice()->setBlocking(false);
         connect( m_comSock, SIGNAL(readyRead()),
                  this, SLOT(parseCdrdaoMessage()));
     }
@@ -220,7 +217,7 @@ void K3b::CdrdaoWriter::prepareArgumentList()
             *m_process << "--device"
                        << K3b::externalBinDeviceParameter(m_sourceDevice, m_cdrdaoBinObject);
         if( defaultToGenericMMC( m_sourceDevice, false ) ) {
-            kDebug() << "(K3b::CdrdaoWriter) defaulting to generic-mmc driver for " << m_sourceDevice->blockDeviceName();
+            qDebug() << "(K3b::CdrdaoWriter) defaulting to generic-mmc driver for " << m_sourceDevice->blockDeviceName();
             *m_process << "--driver" << "generic-mmc";
         }
         setReadArguments();
@@ -241,7 +238,7 @@ void K3b::CdrdaoWriter::setWriteArguments()
                << K3b::externalBinDeviceParameter(burnDevice(), m_cdrdaoBinObject);
 
     if( defaultToGenericMMC( burnDevice(), true ) ) {
-        kDebug() << "(K3b::CdrdaoWriter) defaulting to generic-mmc driver for " << burnDevice()->blockDeviceName();
+        qDebug() << "(K3b::CdrdaoWriter) defaulting to generic-mmc driver for " << burnDevice()->blockDeviceName();
         *m_process << "--driver" << "generic-mmc:0x00000010";
     }
 
@@ -266,7 +263,7 @@ void K3b::CdrdaoWriter::setWriteArguments()
         if( m_cdrdaoBinObject->hasFeature( "disable-burnproof" ) )
             *m_process << "--buffer-under-run-protection" << "0";
         else
-            emit infoMessage( i18n("Cdrdao %1 does not support disabling burnfree.",m_cdrdaoBinObject->version), MessageWarning );
+            emit infoMessage( i18n("Cdrdao %1 does not support disabling burnfree.",m_cdrdaoBinObject->version()), MessageWarning );
     }
 
     if( k3bcore->globalSettings()->force() ) {
@@ -290,7 +287,7 @@ void K3b::CdrdaoWriter::setWriteArguments()
         if( m_cdrdaoBinObject->hasFeature("overburn") )
             *m_process << "--overburn";
         else
-            emit infoMessage( i18n("Cdrdao %1 does not support overburning.",m_cdrdaoBinObject->version), MessageWarning );
+            emit infoMessage( i18n("Cdrdao %1 does not support overburning.",m_cdrdaoBinObject->version()), MessageWarning );
     }
 
 }
@@ -348,7 +345,7 @@ void K3b::CdrdaoWriter::setCopyArguments()
     // source device and source driver
     *m_process << "--source-device" << K3b::externalBinDeviceParameter(m_sourceDevice, m_cdrdaoBinObject);
     if( defaultToGenericMMC( m_sourceDevice, false ) ) {
-        kDebug() << "(K3b::CdrdaoWriter) defaulting to generic-mmc driver for " << m_sourceDevice->blockDeviceName();
+        qDebug() << "(K3b::CdrdaoWriter) defaulting to generic-mmc driver for " << m_sourceDevice->blockDeviceName();
         *m_process << "--source-driver" << "generic-mmc";
     }
 
@@ -364,7 +361,7 @@ void K3b::CdrdaoWriter::setBlankArguments()
                << K3b::externalBinDeviceParameter(burnDevice(), m_cdrdaoBinObject);
 
     if( defaultToGenericMMC( burnDevice(), true ) ) {
-        kDebug() << "(K3b::CdrdaoWriter) defaulting to generic-mmc driver for " << burnDevice()->blockDeviceName();
+        qDebug() << "(K3b::CdrdaoWriter) defaulting to generic-mmc driver for " << burnDevice()->blockDeviceName();
         *m_process << "--driver" << "generic-mmc";
     }
 
@@ -436,10 +433,10 @@ void K3b::CdrdaoWriter::start()
     m_process->setSplitStdout(false);
     m_process->setOutputChannelMode( KProcess::MergedChannels );
     m_process->setFlags( K3bQProcess::RawStdin );
-    connect( m_process, SIGNAL(stdoutLine(const QString&)),
-             this, SLOT(slotStdLine(const QString&)) );
-    connect( m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
-             this, SLOT(slotProcessExited(int, QProcess::ExitStatus)) );
+    connect( m_process, SIGNAL(stdoutLine(QString)),
+             this, SLOT(slotStdLine(QString)) );
+    connect( m_process, SIGNAL(finished(int,QProcess::ExitStatus)),
+             this, SLOT(slotProcessExited(int,QProcess::ExitStatus)) );
 
     m_canceled = false;
     m_knownError = false;
@@ -452,14 +449,14 @@ void K3b::CdrdaoWriter::start()
         return;
     }
 
-    emit debuggingOutput( QLatin1String("Used versions"), QLatin1String( "cdrdao: " ) + m_cdrdaoBinObject->version );
+    emit debuggingOutput( QLatin1String("Used versions"), QString::fromLatin1( "cdrdao: %1" ).arg( m_cdrdaoBinObject->version()) );
 
-    if( !m_cdrdaoBinObject->copyright.isEmpty() )
-        emit infoMessage( i18n("Using %1 %2 - Copyright (C) %3",m_cdrdaoBinObject->name(),m_cdrdaoBinObject->version,m_cdrdaoBinObject->copyright), MessageInfo );
+    if( !m_cdrdaoBinObject->copyright().isEmpty() )
+        emit infoMessage( i18n("Using %1 %2 – Copyright © %3",m_cdrdaoBinObject->name(),m_cdrdaoBinObject->version(),m_cdrdaoBinObject->copyright()), MessageInfo );
 
 
     // the message size changed in cdrdao 1.1.8)
-    if( m_cdrdaoBinObject->version >= K3b::Version( 1, 1, 8 ) )
+    if( m_cdrdaoBinObject->version() >= K3b::Version( 1, 1, 8 ) )
         d->progressMsgSize = sizeof(ProgressMsg2);
     else
         d->progressMsgSize = sizeof(ProgressMsg);
@@ -488,13 +485,19 @@ void K3b::CdrdaoWriter::start()
                 m_backupTocFile = m_tocFile + ".k3bbak";
 
                 // workaround, cdrdao deletes the tocfile when --remote parameter is set
-                if ( !KIO::NetAccess::file_copy(KUrl(m_tocFile),KUrl(m_backupTocFile), (QWidget*) 0) )
-                {
-                    kDebug() << "(K3b::CdrdaoWriter) could not backup " << m_tocFile << " to " << m_backupTocFile;
-                    emit infoMessage( i18n("Could not backup tocfile."), MessageError );
-                    jobFinished(false);
+                KIO::CopyJob* copyJob = KIO::copyAs(QUrl::fromLocalFile(m_tocFile),QUrl::fromLocalFile(m_backupTocFile), KIO::HideProgressInfo);
+                bool copyJobSucceed = true;
+                connect(copyJob, &KJob::result, [&](KJob*) {
+                    if( copyJob->error() != KJob::NoError ) {
+                        qDebug() << "(K3b::CdrdaoWriter) could not backup " << m_tocFile << " to " << m_backupTocFile;
+                        emit infoMessage( i18n("Could not backup tocfile."), MessageError );
+                        jobFinished(false);
+                        copyJobSucceed = false;
+                    }
+                } );
+                copyJob->exec();
+                if( !copyJobSucceed )
                     return;
-                }
             }
         }
         break;
@@ -506,9 +509,9 @@ void K3b::CdrdaoWriter::start()
     // set working dir to dir part of toc file (to allow rel names in toc-file)
     m_process->setWorkingDirectory( QFileInfo( m_tocFile ).absolutePath() );
 
-    kDebug() << "***** cdrdao parameters:\n";
+    qDebug() << "***** cdrdao parameters:\n";
     QString s = m_process->joinedArgs();
-    kDebug() << s << flush;
+    qDebug() << s << flush;
     emit debuggingOutput("cdrdao command:", s);
 
     m_currentTrack = 0;
@@ -548,7 +551,7 @@ void K3b::CdrdaoWriter::start()
     {
         // something went wrong when starting the program
         // it "should" be the executable
-        kDebug() << "(K3b::CdrdaoWriter) could not start cdrdao";
+        qDebug() << "(K3b::CdrdaoWriter) could not start cdrdao";
         emit infoMessage( i18n("Could not start %1.",QString("cdrdao")), K3b::Job::MessageError );
         jobFinished(false);
     }
@@ -559,12 +562,14 @@ void K3b::CdrdaoWriter::start()
         case WRITE:
             if( simulate() )
             {
+                // xgettext: no-c-format
                 emit infoMessage(i18n("Starting DAO simulation at %1x speed...",d->usedSpeed),
                                  K3b::Job::MessageInfo );
                 emit newTask( i18n("Simulating") );
             }
             else
             {
+                // xgettext: no-c-format
                 emit infoMessage( i18n("Starting DAO writing at %1x speed...",d->usedSpeed), K3b::Job::MessageInfo );
                 emit newTask( i18n("Writing") );
             }
@@ -576,11 +581,13 @@ void K3b::CdrdaoWriter::start()
         case COPY:
             if( simulate() )
             {
+                // xgettext: no-c-format
                 emit infoMessage(i18n("Starting simulation copy at %1x speed...",d->usedSpeed), K3b::Job::MessageInfo );
                 emit newTask( i18n("Simulating") );
             }
             else
             {
+                // xgettext: no-c-format
                 emit infoMessage( i18n("Starting copy at %1x speed...",d->usedSpeed), K3b::Job::MessageInfo );
                 emit newTask( i18n("Copying") );
             }
@@ -640,15 +647,15 @@ bool K3b::CdrdaoWriter::cueSheet()
                 return false;
 
             line = line.mid( pos, endPos-pos );
-            QFileInfo fi( QFileInfo( m_tocFile ).path() + "/" + QFileInfo( line ).fileName() );
+            QFileInfo fi( QFileInfo( m_tocFile ).path() + '/' + QFileInfo( line ).fileName() );
             QString binpath = fi.filePath();
-            kDebug() << QString("K3b::CdrdaoWriter::cueSheet() BinFilePath from CueFile: %1").arg( line );
-            kDebug() << QString("K3b::CdrdaoWriter::cueSheet() absolute BinFilePath: %1").arg( binpath );
+            qDebug() << QString("K3b::CdrdaoWriter::cueSheet() BinFilePath from CueFile: %1").arg( line );
+            qDebug() << QString("K3b::CdrdaoWriter::cueSheet() absolute BinFilePath: %1").arg( binpath );
 
             if ( !fi.exists() )
                 return false;
 
-            KTemporaryFile tempF;
+            QTemporaryFile tempF;
             tempF.open();
             QString tempFile = tempF.fileName();
             tempF.remove();
@@ -658,8 +665,8 @@ bool K3b::CdrdaoWriter::cueSheet()
             if ( symlink(QFile::encodeName( m_tocFile ), QFile::encodeName( tempFile + ".cue") ) == -1 )
                 return false;
 
-            kDebug() << QString("K3b::CdrdaoWriter::cueSheet() symlink BinFileName: %1.bin").arg( tempFile );
-            kDebug() << QString("K3b::CdrdaoWriter::cueSheet() symlink CueFileName: %1.cue").arg( tempFile );
+            qDebug() << QString("K3b::CdrdaoWriter::cueSheet() symlink BinFileName: %1.bin").arg( tempFile );
+            qDebug() << QString("K3b::CdrdaoWriter::cueSheet() symlink CueFileName: %1.cue").arg( tempFile );
             m_binFileLnk = tempFile + ".bin";
             m_cueFileLnk = tempFile + ".cue";
             return true;
@@ -688,23 +695,30 @@ void K3b::CdrdaoWriter::slotProcessExited( int exitCode, QProcess::ExitStatus ex
     case WRITE:
     case COPY:
         if ( !m_binFileLnk.isEmpty() ) {
-            KIO::NetAccess::del(KUrl(m_cueFileLnk), (QWidget*) 0);
-            KIO::NetAccess::del(KUrl(m_binFileLnk), (QWidget*) 0);
+            KIO::del(QUrl::fromLocalFile(m_cueFileLnk), KIO::HideProgressInfo);
+            KIO::del(QUrl::fromLocalFile(m_binFileLnk), KIO::HideProgressInfo);
         }
-        else if( (!QFile::exists( m_tocFile ) || K3b::filesize( KUrl(m_tocFile) ) == 0 ) && !m_onTheFly )
+        else if( (!QFile::exists( m_tocFile ) || K3b::filesize( QUrl::fromLocalFile(m_tocFile) ) == 0 ) && !m_onTheFly )
         {
             // cdrdao removed the tocfile :(
             // we need to recover it
-            if ( !KIO::NetAccess::file_copy(KUrl(m_backupTocFile), KUrl(m_tocFile), (QWidget*) 0) )
-            {
-                kDebug() << "(K3b::CdrdaoWriter) restoring tocfile " << m_tocFile << " failed.";
-                emit infoMessage( i18n("Due to a bug in cdrdao the toc/cue file %1 has been deleted. "
-                                       "K3b was unable to restore it from the backup %2.",m_tocFile,m_backupTocFile), MessageError );
-            }
-            else if ( !KIO::NetAccess::del(KUrl(m_backupTocFile), (QWidget*) 0) )
-            {
-                kDebug() << "(K3b::CdrdaoWriter) delete tocfile backkup " << m_backupTocFile << " failed.";
-            }
+            KIO::CopyJob* copyJob = KIO::copyAs(QUrl::fromLocalFile(m_backupTocFile), QUrl::fromLocalFile(m_tocFile), KIO::HideProgressInfo);
+            connect( copyJob, &KJob::result, [&](KJob*) {
+                if( copyJob->error() != KJob::NoError ) {
+                    qDebug() << "(K3b::CdrdaoWriter) restoring tocfile " << m_tocFile << " failed.";
+                    emit infoMessage( i18n("Due to a bug in cdrdao the toc/cue file %1 has been deleted. "
+                                           "K3b was unable to restore it from the backup %2.",m_tocFile,m_backupTocFile), MessageError );
+                } else {
+                    KIO::DeleteJob* deleteJob = KIO::del(QUrl::fromLocalFile(m_backupTocFile), KIO::HideProgressInfo);
+                    connect( deleteJob, &KJob::result, [&](KJob*){
+                        if( deleteJob->error() != KJob::NoError ) {
+                            qDebug() << "(K3b::CdrdaoWriter) delete tocfile backkup " << m_backupTocFile << " failed.";
+                        }
+                    } );
+                    deleteJob->exec();
+                }
+            } );
+            copyJob->exec();
         }
         break;
     case BLANK:
@@ -776,7 +790,9 @@ void K3b::CdrdaoWriter::unknownCdrdaoLine( const QString& line )
         int speed = line.mid( pos+9, po2-pos-9 ).toInt();
         if( speed < d->usedSpeed )
         {
+            // xgettext: no-c-format
             emit infoMessage( i18n("Medium or burner does not support writing at %1x speed",d->usedSpeed), K3b::Job::MessageWarning );
+            // xgettext: no-c-format
             emit infoMessage( i18n("Switching down burn speed to %1x",speed), K3b::Job::MessageWarning );
         }
     }
@@ -794,7 +810,7 @@ void K3b::CdrdaoWriter::reinitParser()
 void K3b::CdrdaoWriter::parseCdrdaoLine( const QString& str )
 {
     emit debuggingOutput( "cdrdao", str );
-    //  kDebug() << "(cdrdaoparse)" << str;
+    //  qDebug() << "(cdrdaoparse)" << str;
     // find some messages from cdrdao
     // -----------------------------------------------------------------------------------------
     if( (str).startsWith( "Warning" ) || (str).startsWith( "MessageWarning" ) || (str).startsWith( "MessageError" ) )
@@ -902,7 +918,7 @@ void K3b::CdrdaoWriter::parseCdrdaoWrote( const QString& line )
 
 void K3b::CdrdaoWriter::parseCdrdaoMessage()
 {
-    static const char msgSync[] = { 0xff, 0x00, 0xff, 0x00 };
+    static const unsigned char msgSync[] = { 0xff, 0x00, 0xff, 0x00 };
     unsigned int avail = m_comSock->bytesAvailable();
     unsigned int msgs = avail / ( sizeof(msgSync)+d->progressMsgSize );
     unsigned int count = 0;
@@ -912,8 +928,8 @@ void K3b::CdrdaoWriter::parseCdrdaoMessage()
     else if ( msgs > 1) {
         // move the read-index forward to the beginnig of the most recent message
         count = ( msgs-1 ) * ( sizeof(msgSync)+d->progressMsgSize );
-        m_comSock->at(count);
-        kDebug() << "(K3b::CdrdaoParser) " << msgs-1 << " message(s) skipped";
+        m_comSock->seek( count );
+        qDebug() << "(K3b::CdrdaoParser) " << msgs-1 << " message(s) skipped";
     }
 
     while( count < avail ) {
@@ -922,10 +938,10 @@ void K3b::CdrdaoWriter::parseCdrdaoMessage()
         int state = 0;
         char buf;
         while( state < 4 ) {
-            buf = m_comSock->getch();
+            m_comSock->getChar( &buf );
             ++count;
             if( count == avail ) {
-                //        kDebug() << "(K3b::CdrdaoParser) remote message sync not found (" << count << ")";
+                //        qDebug() << "(K3b::CdrdaoParser) remote message sync not found (" << count << ")";
                 return;
             }
 
@@ -936,7 +952,7 @@ void K3b::CdrdaoWriter::parseCdrdaoMessage()
         }
 
         if( (avail - count) < d->progressMsgSize ) {
-            kDebug() << "(K3b::CdrdaoParser) could not read complete remote message.";
+            qDebug() << "(K3b::CdrdaoParser) could not read complete remote message.";
             return;
         }
 
@@ -944,7 +960,7 @@ void K3b::CdrdaoWriter::parseCdrdaoMessage()
         ::memset( &d->newMsg, 0, d->progressMsgSize );
         int size = m_comSock->read( (char*)&d->newMsg, d->progressMsgSize);
         if( size == -1 ) {
-            kDebug() << "(K3b::CdrdaoParser) read error";
+            qDebug() << "(K3b::CdrdaoParser) read error";
             return;
         }
         count += size;
@@ -961,13 +977,13 @@ void K3b::CdrdaoWriter::parseCdrdaoMessage()
                     emit nextTrack( d->newMsg.track, d->newMsg.totalTracks );
                     break;
                 case PGSMSG_WCD_LEADIN:
-                    emit newSubTask( i18n("Writing leadin ") );
+                    emit newSubTask( i18n("Writing leadin") );
                     break;
                 case PGSMSG_WCD_DATA:
                     emit nextTrack( d->newMsg.track, d->newMsg.totalTracks );
                     break;
                 case PGSMSG_WCD_LEADOUT:
-                    emit newSubTask( i18n("Writing leadout ") );
+                    emit newSubTask( i18n("Writing leadout") );
                     break;
                 }
 
@@ -1007,14 +1023,14 @@ QString K3b::CdrdaoWriter::findDriverFile( const K3b::ExternalBin* bin )
         return QString();
 
     // cdrdao normally in (prefix)/bin and driver table in (prefix)/share/cdrdao
-    QString path = bin->path;
+    QString path = bin->path();
     path.truncate( path.lastIndexOf("/") );
     path.truncate( path.lastIndexOf("/") );
     path += "/share/cdrdao/drivers";
     if( QFile::exists(path) )
         return path;
     else {
-        kDebug() << "(K3b::CdrdaoWriter) could not find cdrdao driver table.";
+        qDebug() << "(K3b::CdrdaoWriter) could not find cdrdao driver table.";
         return QString();
     }
 }
@@ -1055,7 +1071,7 @@ bool K3b::CdrdaoWriter::defaultToGenericMMC( K3b::Device::Device* dev, bool writ
             return true;
         }
         else {
-            kDebug() << "(K3b::CdrdaoWriter) could not open driver table " << driverTable;
+            qDebug() << "(K3b::CdrdaoWriter) could not open driver table " << driverTable;
             return false;
         }
     }
@@ -1063,4 +1079,4 @@ bool K3b::CdrdaoWriter::defaultToGenericMMC( K3b::Device::Device* dev, bool writ
         return false;
 }
 
-#include "k3bcdrdaowriter.moc"
+
