@@ -26,12 +26,11 @@
 #include "k3bgrowisofshandler.h"
 #include "k3bglobalsettings.h"
 #include "k3bdeviceglobals.h"
+#include "k3b_i18n.h"
 
-#include <klocale.h>
-#include <kdebug.h>
-#include <kglobal.h>
-
-#include <qfile.h>
+#include <QtCore/QDebug>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
 
 #include <unistd.h>
 
@@ -82,10 +81,10 @@ public:
 
     QString multiSessionInfo;
 
-    int burnedMediumType;
+    Device::MediaType burnedMediumType;
 
     K3b::Device::SpeedMultiplicator speedMultiplicator() const {
-        return ( burnedMediumType & K3b::Device::MEDIA_BD_ALL ? K3b::Device::SPEED_FACTOR_BD : K3b::Device::SPEED_FACTOR_DVD );
+        return K3b::speedMultiplicatorForMediaType( burnedMediumType );
     }
 };
 
@@ -100,10 +99,10 @@ K3b::GrowisofsWriter::GrowisofsWriter( K3b::Device::Device* dev, K3b::JobHandler
              this, SLOT(slotThroughput(int)) );
 
     d->gh = new K3b::GrowisofsHandler( this );
-    connect( d->gh, SIGNAL(infoMessage(const QString&, int)),
-             this,SIGNAL(infoMessage(const QString&, int)) );
-    connect( d->gh, SIGNAL(newSubTask(const QString&)),
-             this, SIGNAL(newSubTask(const QString&)) );
+    connect( d->gh, SIGNAL(infoMessage(QString,int)),
+             this,SIGNAL(infoMessage(QString,int)) );
+    connect( d->gh, SIGNAL(newSubTask(QString)),
+             this, SIGNAL(newSubTask(QString)) );
     connect( d->gh, SIGNAL(buffer(int)),
              this, SIGNAL(buffer(int)) );
     connect( d->gh, SIGNAL(deviceBuffer(int)),
@@ -114,8 +113,8 @@ K3b::GrowisofsWriter::GrowisofsWriter( K3b::Device::Device* dev, K3b::JobHandler
     d->process.setSplitStdout(true);
     d->process.setSuppressEmptyLines(true);
     d->process.setFlags( K3bQProcess::RawStdin );
-    connect( &d->process, SIGNAL(stdoutLine(const QString&)), this, SLOT(slotReceivedStderr(const QString&)) );
-    connect( &d->process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotProcessExited(int, QProcess::ExitStatus)) );
+    connect( &d->process, SIGNAL(stdoutLine(QString)), this, SLOT(slotReceivedStderr(QString)) );
+    connect( &d->process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotProcessExited(int,QProcess::ExitStatus)) );
 }
 
 
@@ -137,18 +136,6 @@ QIODevice* K3b::GrowisofsWriter::ioDevice() const
 }
 
 
-bool K3b::GrowisofsWriter::closeFd()
-{
-    if ( d->process.isRunning() ) {
-        d->process.closeWriteChannel();
-        return true;
-    }
-    else {
-        return false;
-    }
-}
-
-
 bool K3b::GrowisofsWriter::prepareProcess()
 {
     d->growisofsBin = k3bcore->externalBinManager()->binObject( "growisofs" );
@@ -157,22 +144,22 @@ bool K3b::GrowisofsWriter::prepareProcess()
         return false;
     }
 
-    if( d->growisofsBin->version < K3b::Version( 5, 10 ) ) {
+    if( d->growisofsBin->version() < K3b::Version( 5, 10 ) ) {
         emit infoMessage( i18n("Growisofs version %1 is too old. "
-                               "K3b needs at least version 5.10.", d->growisofsBin->version ),
+                               "K3b needs at least version 5.10.", d->growisofsBin->version() ),
                           MessageError );
         return false;
     }
 
-    emit debuggingOutput( QLatin1String( "Used versions" ), QLatin1String( "growisofs: " ) + d->growisofsBin->version );
+    emit debuggingOutput( QLatin1String( "Used versions" ), QString::fromLatin1( "growisofs: %1" ).arg(d->growisofsBin->version()) );
 
-    if( !d->growisofsBin->copyright.isEmpty() )
-        emit infoMessage( i18n("Using %1 %2 - Copyright (C) %3",QString("growisofs")
-                               ,d->growisofsBin->version,d->growisofsBin->copyright), MessageInfo );
+    if( !d->growisofsBin->copyright().isEmpty() )
+        emit infoMessage( i18n("Using %1 %2 – Copyright © %3",QString("growisofs")
+                               ,d->growisofsBin->version(),d->growisofsBin->copyright()), MessageInfo );
 
 
     if ( !d->growisofsBin->hasFeature( "buffer" ) ) {
-        emit infoMessage( i18n( "Growisofs version %1 does not feature a software buffer which may result in an unstable burn process.", d->growisofsBin->version ),
+        emit infoMessage( i18n( "Growisofs version %1 does not feature a software buffer which may result in an unstable burn process.", d->growisofsBin->version() ),
                           MessageWarning );
     }
 
@@ -193,17 +180,17 @@ bool K3b::GrowisofsWriter::prepareProcess()
     //        actually write the pad bytes. The only possibility I see right now is to add a padding option
     //        to the pipebuffer.
     int trackSizePadding = 0;
-    if( d->trackSize > 0 && d->growisofsBin->version < K3b::Version( 5, 20 ) ) {
+    if( d->trackSize > 0 && d->growisofsBin->version() < K3b::Version( 5, 20 ) ) {
         if( d->trackSize % 16 ) {
             trackSizePadding = (16 - d->trackSize%16);
-            kDebug() << "(K3b::GrowisofsWriter) need to pad " << trackSizePadding << " blocks.";
+            qDebug() << "(K3b::GrowisofsWriter) need to pad " << trackSizePadding << " blocks.";
         }
     }
 
 
     d->process << d->growisofsBin;
 
-    QString s = burnDevice()->blockDeviceName() + "=";
+    QString s = burnDevice()->blockDeviceName() + '=';
     if( d->image.isEmpty() ) {
         // we always read from stdin
         s += "/dev/fd/0";
@@ -211,8 +198,14 @@ bool K3b::GrowisofsWriter::prepareProcess()
     else
         s += d->image;
 
-    if( d->multiSession && !d->multiSessionInfo.isEmpty() )
-        d->process << "-C" << d->multiSessionInfo;
+    if (d->multiSession && !d->multiSessionInfo.isEmpty()) {
+        QStringList ms = d->multiSessionInfo.split(',');
+        if (ms.size() == 2 && ms[1] != 0) {
+            d->process << "-C" << d->multiSessionInfo;
+        } else {
+            emit infoMessage(i18n("Medium is not of multi-session type and does not contain ISO 9660. Cannot emulate multi-session on it."), MessageError);
+        }
+    }
 
     if( d->multiSession )
         d->process << "-M";
@@ -223,7 +216,7 @@ bool K3b::GrowisofsWriter::prepareProcess()
 
     if( !d->image.isEmpty() ) {
         d->inputFile.setFileName( d->image );
-        d->trackSize = (K3b::filesize( d->image ) + 1024) / 2048;
+        d->trackSize = (QFileInfo(d->image).size() + 1024) / 2048;
         if( !d->inputFile.open( QIODevice::ReadOnly ) ) {
             emit infoMessage( i18n("Could not open file %1.",d->image), MessageError );
             return false;
@@ -294,15 +287,7 @@ bool K3b::GrowisofsWriter::prepareProcess()
         }
 
         if( speed != 0 ) {
-            if ( d->burnedMediumType & K3b::Device::MEDIA_DVD_ALL ) {
-                // speed may be a float number. example: DVD+R(W): 2.4x
-                d->process << QString("-speed=%1").arg( speed%1385 > 0
-                                                         ? QString::number( (float)speed/1385.0, 'f', 1 )
-                                                         : QString::number( speed/1385 ) );
-            }
-            else if ( d->burnedMediumType & K3b::Device::MEDIA_BD_ALL ) {
-                d->process << QString("-speed=%1").arg( QString::number( speed/4496 ) );
-            }
+            d->process << QString("-speed=%1").arg( K3b::formatWritingSpeedFactor( speed, d->burnedMediumType ) );
         }
     }
 
@@ -346,9 +331,9 @@ void K3b::GrowisofsWriter::start()
     }
     else {
 
-        kDebug() << "***** " << d->growisofsBin->name() << " parameters:\n";
+        qDebug() << "***** " << d->growisofsBin->name() << " parameters:\n";
         QString s = d->process.joinedArgs();
-        kDebug() << s << flush;
+        qDebug() << s << flush;
         emit debuggingOutput( d->growisofsBin->name() + " command:", s);
 
 
@@ -371,7 +356,7 @@ void K3b::GrowisofsWriter::start()
         if( !d->process.start( KProcess::MergedChannels ) ) {
             // something went wrong when starting the program
             // it "should" be the executable
-            kDebug() << "(K3b::GrowisofsWriter) could not start " << d->growisofsBin->path;
+            qDebug() << "(K3b::GrowisofsWriter) could not start " << d->growisofsBin->path();
             emit infoMessage( i18n("Could not start %1.",d->growisofsBin->name()), K3b::Job::MessageError );
             jobFinished(false);
         }
@@ -396,7 +381,9 @@ void K3b::GrowisofsWriter::cancel()
 {
     if( active() ) {
         d->canceled = true;
-        closeFd();
+        if ( d->process.isRunning() ) {
+            d->process.closeWriteChannel();
+        }
         d->process.terminate();
     }
 }
@@ -482,7 +469,7 @@ void K3b::GrowisofsWriter::slotReceivedStderr( const QString& line )
                     d->lastWritingSpeed = speed;
                 }
                 else
-                    kDebug() << "(K3b::GrowisofsWriter) speed parsing failed: '"
+                    qDebug() << "(K3b::GrowisofsWriter) speed parsing failed: '"
                              << line.mid( pos, line.indexOf( 'x', pos ) - pos ) << "'" << endl;
             }
             else {
@@ -490,7 +477,7 @@ void K3b::GrowisofsWriter::slotReceivedStderr( const QString& line )
             }
         }
         else
-            kDebug() << "(K3b::GrowisofsWriter) progress parsing failed: '"
+            qDebug() << "(K3b::GrowisofsWriter) progress parsing failed: '"
                      << line.mid( pos+1, line.indexOf( '(', pos ) - pos - 1 ).trimmed() << "'" << endl;
     }
 
@@ -578,4 +565,4 @@ qint64 K3b::GrowisofsWriter::write( const char* data, qint64 maxSize )
     return d->process.write( data, maxSize );
 }
 
-#include "k3bgrowisofswriter.moc"
+
