@@ -16,24 +16,21 @@
 #include "k3bthememanager.h"
 #include "k3bapplication.h"
 
-#include <QApplication>
-#include <QDesktopWidget>
-#include <QEvent>
-#include <QFontMetrics>
-#include <QLabel>
-#include <QPainter>
-#include <QPixmap>
-#include <QString>
+#include <KCoreAddons/KAboutData>
 
-#include <KAboutData>
-#include <KApplication>
-#include <KStandardDirs>
+#include <QtCore/QEvent>
+#include <QtCore/QString>
+#include <QtGui/QFontMetrics>
+#include <QtGui/QPainter>
+#include <QtGui/QPixmap>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDesktopWidget>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QVBoxLayout>
 
 K3b::Splash::Splash( QWidget* parent )
-    : KVBox( parent)
+    : QWidget( parent)
 {
-    setMargin( 0 );
-    setSpacing( 0 );
     setAttribute( Qt::WA_DeleteOnClose );
     setWindowFlags(Qt::FramelessWindowHint|
                    Qt::SplashScreen|
@@ -45,7 +42,7 @@ K3b::Splash::Splash( QWidget* parent )
     pal.setColor( QPalette::WindowText, Qt::white );
     setPalette( pal );
 
-    QLabel* copyrightLabel = new QLabel( KGlobal::mainComponent().aboutData()->copyrightStatement(), this );
+    QLabel* copyrightLabel = new QLabel( KAboutData::applicationData().copyrightStatement(), this );
     copyrightLabel->setMargin( 5 );
     copyrightLabel->setAlignment( Qt::AlignRight );
 
@@ -58,6 +55,13 @@ K3b::Splash::Splash( QWidget* parent )
     m_infoBox = new QLabel( this );
     m_infoBox->setMargin( 5 );
 
+    QVBoxLayout* layout = new QVBoxLayout( this );
+    layout->setContentsMargins( 0, 0, 0, 0 );
+    layout->setSpacing( 0 );
+    layout->addWidget( copyrightLabel );
+    layout->addWidget( picLabel );
+    layout->addWidget( m_infoBox );
+
     // Set geometry, with support for Xinerama systems
     QRect r;
     r.setSize(sizeHint());
@@ -80,7 +84,7 @@ void K3b::Splash::mousePressEvent( QMouseEvent* )
 
 void K3b::Splash::show()
 {
-    KVBox::show();
+    QWidget::show();
     // make sure the splash screen is shown immediately
     qApp->processEvents();
 }
@@ -124,4 +128,4 @@ void K3b::Splash::addInfo( const QString& s )
 // }
 
 
-#include "k3bsplash.moc"
+
