@@ -1,9 +1,10 @@
 /*
  *
  * Copyright (C) 2003-2008 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 2010 Michal Malek <michalm@jabster.pl>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2010 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +23,8 @@
  *@author Sebastian Trueg
  */
 namespace K3b {
+    class ThemeModel;
+    
     class ThemeOptionTab : public QWidget, public Ui::base_K3bThemeOptionTab
     {
         Q_OBJECT
@@ -33,10 +36,17 @@ namespace K3b {
         void readSettings();
         bool saveSettings();
 
+    protected:
+        bool event( QEvent* event ) override;
+
     private Q_SLOTS:
         void selectionChanged();
         void slotInstallTheme();
         void slotRemoveTheme();
+        void slotGetNewThemes();
+        
+    private:
+        ThemeModel* m_themeModel;
     };
 }
 
