@@ -19,45 +19,41 @@
 #include "k3bmsf.h"
 #include "k3bmsfedit.h"
 
-#include <KActionCollection>
-#include <KAction>
-#include <KLocale>
-#include <KMenu>
+#include <KI18n/KLocalizedString>
+#include <KXmlGui/KActionCollection>
 
-#include <QContextMenuEvent>
-#include <QEvent>
-#include <QGridLayout>
-#include <QLabel>
-#include <QLayout>
-#include <QMouseEvent>
+#include <QtCore/QEvent>
+#include <QtGui/QContextMenuEvent>
+#include <QtGui/QMouseEvent>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QMenu>
 
 
 K3b::AudioTrackSplitDialog::AudioTrackSplitDialog( K3b::AudioTrack* track, QWidget* parent )
-    : KDialog( parent),
+    : QDialog( parent),
       m_track(track)
 {
-    QFrame* frame = new QFrame();
-    setMainWidget(frame);
-    setCaption(i18n("Split Audio Track"));
-    setButtons(Ok|Cancel);
-    setDefaultButton(Ok);
+    setWindowTitle(i18n("Split Audio Track"));
 
-    m_editorWidget = new K3b::AudioEditorWidget( frame );
-    m_msfEditStart = new K3b::MsfEdit( frame );
-    m_msfEditEnd = new K3b::MsfEdit( frame );
+    m_editorWidget = new K3b::AudioEditorWidget( this );
+    m_msfEditStart = new K3b::MsfEdit( this );
+    m_msfEditEnd = new K3b::MsfEdit( this );
 
-    QVBoxLayout* layout = new QVBoxLayout( frame );
-    layout->setMargin( 0 );
+    QVBoxLayout* layout = new QVBoxLayout( this );
 
     // FIXME: After the string freeze replace the text with a better one explaning how to use this dialog
     layout->addWidget( new QLabel( i18n("Please select the position where the track should be split."),
-                                   frame ) );
+                                   this ) );
     layout->addWidget( m_editorWidget );
-    
+
     QHBoxLayout* rangeLayout = new QHBoxLayout;
-    rangeLayout->addWidget( new QLabel( i18n("Split track at:"), frame ), 1 );
+    rangeLayout->addWidget( new QLabel( i18n("Split track at:"), this ), 1 );
     rangeLayout->addWidget( m_msfEditStart, 0 );
-    rangeLayout->addWidget( new QLabel( " - ", frame ), 0, Qt::AlignCenter );
+    rangeLayout->addWidget( new QLabel( " - ", this ), 0, Qt::AlignCenter );
     rangeLayout->addWidget( m_msfEditEnd, 0 );
     layout->addLayout( rangeLayout );
 
@@ -65,14 +61,14 @@ K3b::AudioTrackSplitDialog::AudioTrackSplitDialog( K3b::AudioTrack* track, QWidg
     m_editorWidget->enableRangeSelection( true );
     m_editorWidget->installEventFilter( this );
 
-    connect( m_editorWidget, SIGNAL(rangeChanged(int, const K3b::Msf&, const K3b::Msf&)),
-             this, SLOT(slotRangeModified(int, const K3b::Msf&, const K3b::Msf&)) );
+    connect( m_editorWidget, SIGNAL(rangeChanged(int,K3b::Msf,K3b::Msf)),
+             this, SLOT(slotRangeModified(int,K3b::Msf,K3b::Msf)) );
     connect( m_editorWidget, SIGNAL(selectedRangeChanged(int)),
              this, SLOT(slotRangeSelectionChanged(int)) );
-    connect( m_msfEditStart, SIGNAL(valueChanged(const K3b::Msf&)),
-             this, SLOT(slotMsfEditChanged(const K3b::Msf&)) );
-    connect( m_msfEditEnd, SIGNAL(valueChanged(const K3b::Msf&)),
-             this, SLOT(slotMsfEditChanged(const K3b::Msf&)) );
+    connect( m_msfEditStart, SIGNAL(valueChanged(K3b::Msf)),
+             this, SLOT(slotMsfEditChanged(K3b::Msf)) );
+    connect( m_msfEditEnd, SIGNAL(valueChanged(K3b::Msf)),
+             this, SLOT(slotMsfEditChanged(K3b::Msf)) );
 
     setupActions();
 
@@ -84,6 +80,11 @@ K3b::AudioTrackSplitDialog::AudioTrackSplitDialog( K3b::AudioTrack* track, QWidg
     m_editorWidget->addRange( 0, mid-1 );
     m_editorWidget->addRange( mid, m_track->length()-1 );
 
+    QDialogButtonBox* buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this );
+    connect( buttonBox, SIGNAL(accepted()), SLOT(accept()) );
+    connect( buttonBox, SIGNAL(rejected()), SLOT(reject()) );
+    layout->addWidget( buttonBox );
+
     slotRangeSelectionChanged( 0 );
 }
 
@@ -95,15 +96,15 @@ K3b::AudioTrackSplitDialog::~AudioTrackSplitDialog()
 
 void K3b::AudioTrackSplitDialog::setupActions()
 {
-    m_popupMenu = new KMenu( this );
+    m_popupMenu = new QMenu( this );
 
-    KAction* actionSplitHere = new KAction( this );
+    QAction* actionSplitHere = new QAction( this );
     actionSplitHere->setText( i18n("Split Here") );
-    connect( actionSplitHere, SIGNAL( triggered() ), this, SLOT( slotSplitHere() ) );
+    connect( actionSplitHere, SIGNAL(triggered()), this, SLOT(slotSplitHere()) );
 
-    KAction* actionRemoveRange = new KAction( this );
+    QAction* actionRemoveRange = new QAction( this );
     actionRemoveRange->setText( i18n("Remove part") );
-    connect( actionRemoveRange, SIGNAL( triggered() ), this, SLOT( slotRemoveRange() ) );
+    connect( actionRemoveRange, SIGNAL(triggered()), this, SLOT(slotRemoveRange()) );
 
     m_popupMenu->addAction( actionSplitHere );
     m_popupMenu->addAction( actionRemoveRange );
@@ -180,7 +181,7 @@ bool K3b::AudioTrackSplitDialog::eventFilter( QObject* o, QEvent* e )
         }
     }
 
-    return KDialog::eventFilter( o, e );
+    return QDialog::eventFilter( o, e );
 }
 
 
@@ -236,4 +237,4 @@ void K3b::AudioTrackSplitDialog::splitTrack( K3b::AudioTrack* track,
     }
 }
 
-#include "k3baudiotracksplitdialog.moc"
+
